<?php
/**
 * Plugin Name: Compteur de téléchargement
 * Description: Ce plugin enregistre le nombre de clics sur des liens avec la classe 'compte-lien'.
 * Version: 1.0.0
 * Author: WP-CODES
 * Author URI: https://wp-codes.fr
 * Text Domain: compteur-telechargement
 */

if (!defined('ABSPATH')) {
    exit;
}
//include fichiers
require_once(__DIR__ . '/admin/compteur-admin.php');


function compteur_enqueue_scripts() {
    //if (!is_admin()) {
        wp_enqueue_script('jquery');
        wp_enqueue_script(
            'compteur-js', 
            plugin_dir_url(__FILE__) . 'assets/js/compteur.js', 
            array('jquery'), 
            '1.0.0', 
            true
        );

        // Passer l'URL d'Ajax pour le front
        wp_localize_script('compteur-js', 'ajaxurl', admin_url('admin-ajax.php'));

        // Récupérer les sélecteurs directement sous forme de chaîne
        $custom_selectors = get_option('compteur_selecteurs_css', '');

        // Passer les sélecteurs au script JS
        wp_localize_script('compteur-js', 'compteur_selecteurs_css', $custom_selectors);
    //}
}
add_action('wp_enqueue_scripts', 'compteur_enqueue_scripts');

// Enqueue pour le back-office (gérer les purges)
function compteur_enqueue_admin_scripts() {
    wp_enqueue_script('jquery');
    wp_enqueue_script(
        'compteur-admin-js', 
        plugin_dir_url(__FILE__) . 'assets/js/compteur-admin.js', // Nouveau fichier spécifique à l'admin
        array('jquery'), 
        '1.0.0', 
        true
    );

    // Passer l'URL d'Ajax pour l'admin
    wp_localize_script('compteur-admin-js', 'ajaxurl', admin_url('admin-ajax.php'));
}
add_action('admin_enqueue_scripts', 'compteur_enqueue_admin_scripts');

// Fonction pour créer la table de comptage des clics lors de l'activation du plugin
function compteur_creer_table() {
    global $wpdb;

    $table_name = $wpdb->prefix . 'compteur_liens';
    
    // Structure SQL pour créer la table
    $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE IF NOT EXISTS $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        lien varchar(255) NOT NULL,
        clics bigint(20) DEFAULT 0 NOT NULL,
        PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
}

// Enregistrer la fonction lors de l'activation du plugin
register_activation_hook(__FILE__, 'compteur_creer_table');


// Ajouter le menu dans le back-office
add_action('admin_menu', 'compteur_menu_admin');

add_action('admin_init', 'compteur_register_settings');
function compteur_register_settings() {
    register_setting('compteur_options_group', 'compteur_selecteurs_css', 'sanitize_text_field');
}

/*
add_action('wp_footer', 'compteur_ajouter_js');
function compteur_ajouter_js() {
    $custom_selectors = esc_js(get_option('compteur_selecteurs_css')); // Mettre le bon nom d'option
    ?>
    <script type="text/javascript">
        jQuery(document).ready(function($) {
            var selectors = '<?php echo $custom_selectors; ?>';
            if (selectors) {
                $(selectors).each(function() {
                    var lien = $(this).find('a'); // Cibler la balise <a> à l'intérieur des boutons
                    if (lien.length) {
                        lien.addClass('compte-lien'); // Ajouter la classe 'compte-lien'
                    }
                });
            }
        });
    </script>
    <?php
}
*/

// Associer l'action AJAX pour les utilisateurs connectés et non connectés
add_action('wp_ajax_enregistrer_clic', 'enregistrer_clic');
add_action('wp_ajax_nopriv_enregistrer_clic', 'enregistrer_clic'); // Pour les utilisateurs non connectés

function enregistrer_clic() {
    global $wpdb;

    // Vérifier si le paramètre 'lien' est présent dans la requête POST
    if (isset($_POST['lien'])) {
        $lien = sanitize_text_field($_POST['lien']); // Nettoyer le texte reçu
        $table_name = $wpdb->prefix . 'compteur_liens';

        // Vérifier si le lien existe déjà dans la table
        $result = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE lien = %s", $lien));

        if ($result) {
            // Si le lien existe, incrémenter le compteur de clics
            $wpdb->update($table_name, array('clics' => $result->clics + 1), array('lien' => $lien));
        } else {
            // Sinon, insérer un nouveau lien avec un compteur à 1
            $wpdb->insert($table_name, array('lien' => $lien, 'clics' => 1));
        }

        wp_send_json_success('Clic enregistré');
    } else {
        // Retourner une erreur si le paramètre 'lien' est manquant
        wp_send_json_error('Paramètre "lien" manquant');
    }
}

add_action('wp_ajax_supprimer_clic', 'supprimer_clic');
add_action('wp_ajax_nopriv_supprimer_clic', 'supprimer_clic');

function supprimer_clic() {
    global $wpdb;

    // Vérifier si l'ID est présent dans la requête
    if (isset($_POST['id'])) {
        $id = intval($_POST['id']);
        $table_name = $wpdb->prefix . 'compteur_liens';

        // Supprimer la ligne correspondante
        $deleted = $wpdb->delete($table_name, array('id' => $id));

        if ($deleted) {
            wp_send_json_success('Compteur supprimé');
        } else {
            wp_send_json_error('Erreur lors de la suppression');
        }
    } else {
        wp_send_json_error('ID manquant');
    }
}





